==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProberSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProberSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProberSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.ProberSpec,io.fabric8.openshift.api.model.monitoring.v1.ProberSpecBuilder>{
  public ProberSpecBuilder() {
    this(false);
  }
  public ProberSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ProberSpec(), validationEnabled);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProberSpec(), validationEnabled);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance) {
    this(fluent, instance, false);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPath(instance.getPath()); 
    fluent.withScheme(instance.getScheme()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance) {
    this(instance,false);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPath(instance.getPath()); 
    this.withScheme(instance.getScheme()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.ProberSpec build() {
    ProberSpec buildable = new ProberSpec(fluent.getPath(),fluent.getScheme(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProberSpecBuilder that = (ProberSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProberSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProberSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProberSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.ProberSpec,io.fabric8.openshift.api.model.monitoring.v1.ProberSpecBuilder>{
  public ProberSpecBuilder() {
    this(false);
  }
  public ProberSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ProberSpec(), validationEnabled);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProberSpec(), validationEnabled);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance) {
    this(fluent, instance, false);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPath(instance.getPath()); 
    fluent.withProxyUrl(instance.getProxyUrl()); 
    fluent.withScheme(instance.getScheme()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance) {
    this(instance,false);
  }
  public ProberSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProberSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPath(instance.getPath()); 
    this.withProxyUrl(instance.getProxyUrl()); 
    this.withScheme(instance.getScheme()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.ProberSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.ProberSpec build() {
    ProberSpec buildable = new ProberSpec(fluent.getPath(),fluent.getProxyUrl(),fluent.getScheme(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProberSpecBuilder that = (ProberSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
